package de.jottyfan.timetrack.modules.done;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

import javax.enterprise.context.RequestScoped;
import javax.faces.context.FacesContext;
import javax.inject.Inject;
import javax.inject.Named;

import de.jooqfaces.JooqFacesContext;
import de.jottyfan.timetrack.help.Navigation;
import de.jottyfan.timetrack.help.Pages;
import de.jottyfan.timetrack.modules.ControlInterface;

/**
 * 
 * @author henkej
 * 
 */
@Named
@RequestScoped
public class DoneControl extends Navigation implements ControlInterface, Serializable {
	private static final long serialVersionUID = 1L;

	@Inject
	@Named("doneModel")
	private DoneModel model;

	public String toStart() {
		return navigateTo(Pages.START);
	}

	public String toList() {
		boolean ready = model.init((JooqFacesContext) FacesContext.getCurrentInstance());
		return ready ? navigateTo(Pages.DONE_INIT) : toStart();
	}

	public String toAdd() {
		DoneBean bean = new DoneBean();
		bean.setTimeFrom(LocalDateTime.now());
		model.setBean(bean);
		boolean ready = model.loadDefaults((JooqFacesContext) FacesContext.getCurrentInstance());
		return ready ? navigateTo(Pages.DONE_ADD) : toList();
	}

	public String toEdit(DoneBean bean) {
		model.setBean(bean);
		boolean ready = model.loadDefaults((JooqFacesContext) FacesContext.getCurrentInstance());
		return ready ? navigateTo(Pages.DONE_EDIT) : toList();
	}

	public String toDelete(DoneBean bean) {
		model.setBean(bean);
		return navigateTo(Pages.DONE_DELETE);
	}

	public String toRead() {
		boolean ready = model.prepareRead((JooqFacesContext) FacesContext.getCurrentInstance());
		return ready ? navigateTo(Pages.DONE_READ) : toStart();
 	}
	
	public String doUpdate() {
		boolean ready = model.update((JooqFacesContext) FacesContext.getCurrentInstance());
		return ready ? toList() : toEdit(model.getBean());
	}

	public String doDelete() {
		boolean ready = model.delete((JooqFacesContext) FacesContext.getCurrentInstance());
		return ready ? toList() : toDelete(model.getBean());
	}

	public String doAdd() {
		boolean ready = model.insert((JooqFacesContext) FacesContext.getCurrentInstance());
		return ready ? toList() : toAdd();
	}
	
	public String doDownload() {
		boolean ready = model.download((JooqFacesContext) FacesContext.getCurrentInstance());
		return ready ? "" : "";
	}

	public String getCurrentTimeAsString() {
		DateTimeFormatter hhmmss = DateTimeFormatter.ofPattern("HH:mm:ss");
		return LocalDateTime.now().format(hhmmss);
	}
}
