package de.jottyfan.timetrack.modules.done;

import java.awt.Color;
import java.util.HashMap;
import java.util.Map;

/**
 * 
 * @author henkej
 *
 */
public class RgbColor {

	/**
	 * find a rgb color code for the combination of the given params
	 * 
	 * @param bigInfluence
	 * @param mediumInfluence
	 * @param littleInfluence
	 * @return the hex color code
	 */
	public String determineRgbColor(String bigInfluence, String mediumInfluence, String littleInfluence) {
		int big = bigInfluence == null ? 0 : bigInfluence.hashCode();
		int med = mediumInfluence == null ? 0 : mediumInfluence.hashCode();
		int lit = littleInfluence == null ? 0 : littleInfluence.hashCode();
		
		float bI = (1f / String.valueOf(big).length());
		float mI = (0.5f / String.valueOf(med).length());
		float lI = (0.25f / String.valueOf(lit).length());
		
		float r = 0.0f + bI + mI + lI; // + makes it brighter
		float g = 0.5f - bI - mI - lI; // - makes it darker
		float b = 0.5f - bI - mI - lI;
		
		r = r < 0 ? r * -1 : r;
		r = r > 1.0f ? 1 / r : r;
		g = g < 0 ? g * -1 : g;
		g = g > 1.0f ? 1 / g : g;
		b = b < 0 ? b * -1 : b;
		b = b > 1.0f ? 1 / b : b;
		
		Color c = new Color(r, g, b);
		return new StringBuilder("rgb(").append(c.getRed()).append(",").append(c.getGreen()).append(",").append(c.getBlue())
				.append(")").toString();
	}
	
	/**
	 * find the corresponding rgb color for the css key
	 * @param cssKey the key
	 * @return the hex color code
	 */
	public String determineColorFromCssKey(String cssKey) {
		// for now, only map the css key to a defined list
		Map<String, String> map = new HashMap<>();
		map.put("TA3", "rgb(0, 255, 0)");
		map.put("WP2", "rgb(192, 192, 0)");
		map.put("WP4", "rgb(32, 192, 255)");
		map.put("WP5", "rgb(255, 0, 0)");
		return map.get(cssKey);
	}

	public String determineTextcolorFromCssKey(String cssKey) {
		Map<String, String> map = new HashMap<>();
		map.put("TA3", "rgb(0, 0, 0)");
		map.put("WP2", "rgb(0, 0, 0)");
		map.put("WP4", "rgb(0, 0, 0)");
		map.put("WP5", "rgb(0, 0, 0)");
		String value = map.get(cssKey);
		return value == null ? "rgb(255, 255, 255)" : value;
	}
}
